=======
History
=======

0.1.1 (04/27/2016)
~~~~~~~~~~~~~~~~~~

* Moved to github churchill-lab space
* First release onto PyPI

0.1.0 (01/22/2016)
~~~~~~~~~~~~~~~~~~

* Started a private project on bitbucket.
